# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.64
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.64) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Class-Singleton
Version:	1.6
Release:	1.%{__distinit}%{__distvers}
Summary:	Implementation of a "Singleton" class
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Class-Singleton
Source0:	https://cpan.metacpan.org/modules/by-module/Class/Class-Singleton-%{version}.tar.gz
Patch0:		Class-Singleton-1.6-old-EU::MM.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(Test::More)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This is the Class::Singleton module. A Singleton describes an object class
that can have only one instance in any system. An example of a Singleton
might be a print spooler or system registry. This module implements a
Singleton class from which other classes can be derived. By itself, the
Class::Singleton module does very little other than manage the
instantiation of a single object. In deriving a class from
Class::Singleton, your module will inherit the Singleton instantiation
method and can implement whatever specific functionality is required.

%prep
%setup -q -n Class-Singleton-%{version}

# We don't really need ExtUtils::MakeMaker ≥ 6.64
%if %{old_eumm}
%patch0
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%if 0%{?_licensedir:1}
%license Artistic Copying LICENCE
%else
%doc Artistic Copying LICENCE
%endif
%doc Changes README
%{perl_vendorlib}/Class/
%{_mandir}/man3/Class::Singleton.3*

%changelog
* Thu Dec  3 2020 Paul Howarth <paul@city-fan.org> - 1.6-1
- Update to 1.6
  - Fixed confusing Changes entry about Perl's licensing terms (CPAN RT#132843)
  - Added optional Changes testing (skipped unless AUTHOR_TESTING)
  - Reformatted Changes file as per CPAN::Changes::Spec
  - Added optional POD coverage testing (skipped unless AUTHOR_TESTING)
  - Added optional Perl::Critic testing (skipped unless AUTHOR_TESTING)
  - Made code Perl::Critic clean
  - Added optional POD testing (skipped unless AUTHOR_TESTING)
  - Included GitHub repository URLs in metadata now that source code has been
    uploaded to GitHub (as of version 1.5)
  - Included META.json file in addition to META.yml
  - Set minimum required ExtUtils::MakeMaker version to 6.64 to ensure that all
    parameters used are supported, to save jumping through hoops to support
    earlier versions (this should not be a problem since ExtUtils::MakeMaker
    6.64 is easily installed into Perl 5.8.1 and above, that being the whole
    point of the new choice of minimum supported Perl version)
  - Set minimum required Perl version to 5.8.1; this is in line with the
    minimum requirement of the "Perl Toolchain"
  - Corrected typo in a comment (CPAN RT#86336)
- Package Artistic, Copying and LICENCE licence files
- Add patch to support building with ExtUtils::MakeMaker < 6.64

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 1.5-13
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop legacy BuildRoot: and Group: tags

* Tue Aug  9 2016 Paul Howarth <paul@city-fan.org> - 1.5-5
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Nov 10 2014 Paul Howarth <paul@city-fan.org> - 1.5-1
- Update to 1.5
  - Work around global destruction order issue (CPAN RT#23568/68526)
- This release by SHAY ⇒ update source URL
- Drop %%defattr, redundant since rpm 4.4
- Classify buildreqs by usage

* Thu Jun  7 2012 Paul Howarth <paul@city-fan.org> - 1.4-11
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 1.4-10
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.4-9
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.4-8
- Fix dist tag for RHEL-6 Beta

* Fri Jan 22 2010 Paul Howarth <paul@city-fan.org> - 1.4-7
- Import from Fedora

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.4-6
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.4-3
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.4-2
- Rebuild for new perl

* Mon Oct 15 2007 Steven Pritchard <steve@kspei.com> - 1.4-1
- Update to 1.4
- Update License tag
- Drop our copy of the license text
- Improve Summary
- Make description match cpanspec output
- BR Test::More

* Tue Apr 17 2007 Steven Pritchard <steve@kspei.com> - 1.03-4
- Use fixperms macro instead of our own chmod incantation
- BR ExtUtils::MakeMaker

* Sat Sep 16 2006 Steven Pritchard <steve@kspei.com> - 1.03-3
- Canonicalize Source0 URL
- Fix find option order

* Thu Sep 08 2005 Steven Pritchard <steve@kspei.com> - 1.03-2
- Fix permissions on Singleton.pm

* Wed Aug 31 2005 Steven Pritchard <steve@kspei.com> - 1.03-1
- Specfile autogenerated
